<?php
namespace Neuron\Person\Controller;

use Neuron\Person\Experiences;
use Neuron\Person\Experience as ExperienceModel;
use Neuron\Generic\Result;

class Experience extends \Neuron\Person\Controller {

	protected function getView($name, $variables = array()){
		/* default layout & view prefix */
		$layout = 'neuron/person/layout/form';
		$prefix = 'neuron/person/experience';

		/* libraries */
		$this->using('jquery', null, false)
		->using('bootstrap', null)
		->using('font-awesome', null)
		->using('bootbox');

		/* get layout n view prefix from config */
		$config = $this->getConfig();
		if (isset($config['task'])) {
		$config = $config['task'];
		$layout = isset($config['formlayout']) ? $config['formlayout'] : $layout;
		$prefix = isset($config['viewprefix']) ? $config['viewprefix'] : $prefix;
		}


		// Script FCM
			$config = $this->getConfig();
	        $opt = new Notification\FCM\Options();
	        $opt->push($config['notification']['fcm']);
	        
	        $template = new Notification\Template(Notification\Template\Storage::factory($this->getDb(), $this->getConfig()));
	        
	        $fcm = new Notification\FCM(
	            Notification\Email\Storage::factory($this->getDb(), $this->getConfig()),
	            $template,
	            $opt
	        );
	        
	        $id_user = $this->userID();
	        $script = $fcm->listen('firebaseHandler', $id_user, $this->getPublicUrl());
			
		$variables['script'] = $script;

		/* set layout and view */
		$this->layout($layout);

		$view = new \Zend\View\Model\ViewModel($variables);
		$view->setTemplate($prefix . '/' . strtolower($name));

		return $view;
	}

	protected function getViewPartial($name, $variables = array()){
		$prefix = 'neuron/person/experience';
		$config = $this->getConfig();
		if (isset($config['task'])) {
			$config = $config['task'];
			$prefix = isset($config['viewprefix']) ? $config['viewprefix'] : $prefix;
		}

		$view = new \Zend\View\Model\ViewModel($variables);
		$view->setTemplate($prefix . '/' . strtolower($name)); // path to phtml file under view folder
		return $view;
	}

	// MOVED TO /controller/widget/experience
	public function formAction()
	{
		$post = $this->getPostParams();
		$id = $post['id'];
		$person_id = $post['person_id'];
		$expdata = array();
		$title = "Create Experience";

		if($id){
			$storage = \Neuron\Person\Experience\Storage::factory($this->getDb(), $this->getConfig());
			$cexp = new \Neuron\Person\Experience($storage);
			$title = "Edit Experience";
			if ($cexp->load($id))  {
				$expdata = $cexp->pull();
			}
		}

		return $this->getViewPartial('crud', get_defined_vars());
	}
	
	public function listAction() {
		$result = new Result();
        $session = $this->getSession()->get();
        $post = $this->getRest()->getParameters();


        $personId = $post['person_id'];
        try {
            $Experiences = new Experiences(ExperienceModel\Storage::factory($this->getDb(),$this->getConfig()));
            $dataExperiences = $Experiences->load($personId, ExperienceModel\Storage::LISTBY_PERSON_TYPE);
            $result->data = $dataExperiences->data['list'];
        } catch (\Exception $th) {
            $result->code = 500;
            $result->info = $this->translate("failed loading experiences");
        }

        $requestPost = array(
			'guid' => '',
			'code' => '',
			'info' => '',
			'data' => $post
		); 
		
		$responseResult = array(
			'guid' => $result->guid,
			'code' => $result->code,
			'info' => $result->info,
			'data' => $result->data
		); 
		
		$logparam['subject'] = 'API PERSON LOAD FAMILY';
		$logparam['identity'] = $personId ? $personId : '';
		$logparam['user'] = $session['user_id'] ? $session['user_id'] : '';
		$logparam['description'] = 'Log proses api person load family';
		$logparam['request'] = json_encode($requestPost);
		$logparam['response'] = json_encode($responseResult);
		
		$this->writeLogAction($logparam);
		
        return $this->getREST()->getResponse($result);
	}

	public function loadAction() {
		$result = new Result();
        $session = $this->getSession()->get();
        $post = $this->getRest()->getParameters();


        $experience_id = $post['experience_id'];
        try {
            $experience = new ExperienceModel(ExperienceModel\Storage::factory($this->getDb(),$this->getConfig()));
            $experience->load($experience_id, ExperienceModel\Storage::LOADBY_ID);
            $result->data = $experience->pull();
            
        } catch (\Exception $th) {
            $result->code = 500;
            $result->info = $this->translate("failed loading experience");
        }

        $requestPost = array(
			'guid' => '',
			'code' => '',
			'info' => '',
			'data' => $post
		); 
		
		$responseResult = array(
			'guid' => $result->guid,
			'code' => $result->code,
			'info' => $result->info,
			'data' => $result->data
		); 
		
		$logparam['subject'] = 'API PERSON LOAD FAMILY';
		$logparam['identity'] = $experience_id ? $experience_id : '';
		$logparam['user'] = $session['user_id'] ? $session['user_id'] : '';
		$logparam['description'] = 'Log proses person load family';
		$logparam['request'] = json_encode($requestPost);
		$logparam['response'] = json_encode($responseResult);
		
		$this->writeLogAction($logparam);
		
        return $this->getREST()->getResponse($result);
	}

	public function saveAction() {
		$result = new Result();
		$storage = \Neuron\Person\Experience\Storage::factory($this->getDb(), $this->getConfig());
		
		$post = $this->getRest()->getParameters();
		
		if (!empty($post['experience_id'])) {
			$update = true;
		} else {
			$post['experience_id'] = null;
			$update = false;
		}

		$post['period_start'] = (isset($post['period_start']) && !empty($post['period_start']))? date('Ym', strtotime($post['period_start'])) : null;
		$post['period_end'] = (isset($post['period_end']) && !empty($post['period_end']))? date('Ym', strtotime($post['period_end'])) : null;

		try {
            $Experience = new ExperienceModel(ExperienceModel\Storage::factory($this->getDb(),$this->getConfig()));
            $result = $Experience->create($post);
        } catch (\Exception $th) {
            $result->code = 500;
            $result->info = $this->translate("failed save Experience");
        }
		
		$requestPost = array(
			'guid' => '',
			'code' => '',
			'info' => '',
			'data' => $post
		); 

		$logparam['subject'] = 'PERSON SAVE EXPERIENCE';
		$logparam['identity'] = $this->getSession()->owner();;
		$logparam['data1'] = $result->data;
		$logparam['description'] = 'Log proses person save experience';
		$logparam['request'] = json_encode($requestPost);
		$logparam['response'] = json_encode($result->data);

		$this->writeLogAction($logparam);
		
		return $this->getREST()->getResponse($result);
	}

	public function deleteAction() {
		$result = new Result();
        $session = $this->getSession()->get();
        $post = $this->getRest()->getParameters();


        $experience_id = $post['experience_id'];
        try {
            $experience = new ExperienceModel(ExperienceModel\Storage::factory($this->getDb(),$this->getConfig()));
            $result = $experience->delete($experience_id);
        } catch (\Exception $th) {
            $result->code = 500;
            $result->info = $this->translate("failed loading relation");
        }

        $requestPost = array(
			'guid' => '',
			'code' => '',
			'info' => '',
			'data' => $post
		); 
		
		$responseResult = array(
			'guid' => $result->guid,
			'code' => $result->code,
			'info' => $result->info,
			'data' => $result->data
		); 
		
		$logparam['subject'] = 'API PERSON DELETE EXPERIENCE';
		$logparam['identity'] = $experience_id ? $experience_id : '';
		$logparam['user'] = $session['user_id'] ? $session['user_id'] : '';
		$logparam['description'] = 'Log proses person delete experience';
		$logparam['request'] = json_encode($requestPost);
		$logparam['response'] = json_encode($responseResult);
		
		$this->writeLogAction($logparam);
		
        return $this->getREST()->getResponse($result);
	}

}
