<?php
namespace Neuron\Person;

use Neuron\Person\Entity;
use Neuron\Person\Entity\Storage;
use Neuron\Generic\Result;

class Entities extends \Neuron\Generic\Set {
		
	protected $_storage;

	public function __construct(\Neuron\Person\Entity\Storage\Skeleton $storage) {
			
		$this->_storage = $storage;
	}

	public function listPerson($params) {
		try {
			$result = $this->_storage->listPerson($params);
			$draw = (isset($params['draw']) ? $params['draw']:null);
			
			$retval = array(
					'draw' => $draw,
					'recordsTotal' => $result['total'],
					'recordsFiltered' => $result['filtered'],
					'data' => $result['data'],
			);
            
			return $retval;
		} catch (\Exception $ex) {
			$retval = array(
                'draw' => $draw,
                'recordsTotal' => 0,
                'recordsFiltered' => 0,
                'data' => [],
                'info' => $ex->getMessage()
            );
		}
	}

	public function load($id = null, $mode = Storage::LIST_ALL,$params = array()){
        $result     = new Result();
        $data       = $this->_storage->loadList($id,$mode,$params);
        
        if($data){
            $rows   = $data->rows;
            $list   = array();

            if($rows){
                foreach($rows as $row){
                    $row = array_change_key_case($row);
                    unset($row['b_rownum']);
    
                    $entity     = new Entity($this->_storage);
                    $entity->push($data);
                    $this->add($entity);
                    $list[]     = $row;
                }
            }
            
            $resData        = array(
                'rows'      => $list,
                'countTotal' => $data->countTotal
            );
            $result->data   = $resData;
            $result->info   = "Success loading Person data";

        }else{
            $result->code = 411;
            $result->info = 'Failed loading data';
        }

        return $result;
    }

}
