<?php
namespace Neuron\Person;

use Neuron\Generic\Entity\Map;
use Neuron\Generic\Result;
use Neuron\Contact\Address\City;

class Experience extends \Neuron\Generic\Entity\Mapper {
    
    protected $_storage;

    public function __construct(\Neuron\Person\Experience\Storage\Skeleton $storage, $data = array()) {

        $this->_storage = $storage;

        parent::__construct(
            $data, 
            array(
                new Map('experience_id'),
                new Map('person_id'),
                new Map('company_name'),
                new Map('position'),
                new Map('job_desc'),
                new Map('period_start'),
                new Map('period_end'),
                new Map('location')
            ), 
            parent::CASE_INSENSITIVE
        );
    }
	
    public function load($id) {
        if ($data = $this->_storage->load($id)) {
            $this->push($data);
            return true;
        }
        return false;
    }

    public function save($update = false){
        if ($id = $this->_storage->save($this, $update)) {
            $this->experience_id = $id;
            return true;
        }
        return false;
    }

    public function delete($id) {
		/* init */
		$result = new Result();
		try {
			/* loaded? */
		
			if ($this->_storage->remove($id)) {

				$result->info = 'experience_trm_success';
			} else {

				//gagal
				$result->code = 51;
				$result->info = 'experience_trm_failed';

			}
				
			return $result;
		} catch (\Exception $ex) {
			error_log('Error at ' . $ex->getFile() . ' line ' . $ex->getLine() . ': ' . $ex->getMessage());
			$result->code = 500;
			$result->info = $ex->getMessage();
			return $result;
		}
    }

	public function create($data = array())
    {
		$result = new Result();
		$update = false;
		if($data['experience_id']){
			$update = true;
		}

		//create data relation
		$param = $this->pull();
		foreach($data as $k => $v){
			if(array_key_exists($k, $param)){
				$param[$k] = $v;
			}
		}

		$this->push($param);
		if($this->save($update)){
			$result->data = $this->experience_id;
		}
		return $result;
    }

    public function city(){
        $city     = new City(City\Storage::factory(
            $this->_storage->getAdapter(),
            $this->_storage->getConfig()
        ));
        $city->load($this->location);
        return $city;
    }
    
}